@@ -2,10 +2,10 @@
 
 #
 # DaVinci Resolve Multi Debian package creator
-# Release 2021-01-07
+# Release 2021-02-10
 # By Daniel Tufvesson
 #
-MAKERESOLVEDEB_VERSION=1.4.4
+MAKERESOLVEDEB_VERSION=1.4.5
 
 check_command() {
     echo -n "Checking for ${1}..."
@@ -47,6 +47,10 @@ create_directory() {
 	mkdir -p "$1"
 	chmod 755 "$1"
     fi
+    if ! [[ -w "$1" ]] ; then
+	echo "[ERROR: DIRECTORY NOT WRITABLE] $1"
+	ERRORS=$((ERRORS+1))
+    fi
 }
 
 createf_directory() {
@@ -54,6 +58,10 @@ createf_directory() {
 	chmod a+w -R ${1}
 	rm -rf ${1}
     fi
+    if [[ -e "${1}" ]] ; then
+	echo "[ERROR: UNABLE TO REPLACE DIRECTORY] $1"
+	ERRORS=$((ERRORS+1))	
+    fi
     create_directory "$1"
 }
 
@@ -77,12 +85,18 @@ extract_tgz() {
 }
 
 init_deb() {
+    if [[ -z "$MAINTAINER" ]];
+    then
+	MAINTAINER=$(whoami)@$(hostname)
+    fi
     create_directory ${DEB_DIR}/DEBIAN
     cat > ${DEB_DIR}/DEBIAN/control <<EOF
 Package: ${DEB_NAME}
 Version: ${DEB_VERSION}
+Section: video
+Priority: optional
 Architecture: amd64
-Maintainer: Blackmagic Design
+Maintainer: ${MAINTAINER}
 Description: ${RESOLVE_NAME} made from ${INSTALLER_ARCHIVE} using MakeResolveDeb ${MAKERESOLVEDEB_VERSION}
 Conflicts: ${DEB_CONFLICTS}
 EOF
@@ -225,8 +239,8 @@ process16() {
 
     # Create symlinks
     create_directory ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/
-    link_object /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/libBlackmagicRawAPI.so
-    link_object /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/libBlackmagicRawAPI.so
+    link_object ../libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/libBlackmagicRawAPI.so
+    link_object ../../libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/libBlackmagicRawAPI.so
 
     # Create common data dir
     create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
@@ -318,8 +332,8 @@ process17() {
 
     # Create symlinks
     create_directory ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/
-    link_object /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/libBlackmagicRawAPI.so
-    link_object /opt/resolve/libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/libBlackmagicRawAPI.so
+    link_object ../libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/libBlackmagicRawAPI.so
+    link_object ../../libs/libBlackmagicRawAPI.so ${RESOLVE_BASE_DIR}/bin/BlackmagicRawAPI/libBlackmagicRawAPI.so
 
     # Create common data dir
     create_directory ${DEB_DIR}/var/BlackmagicDesign/DaVinci\ Resolve
@@ -469,10 +483,18 @@ EOF
 
 echo "MakeResolveDeb ${MAKERESOLVEDEB_VERSION}"
 
+# Warn if running as root
+if [[ $EUID -eq 0 ]];
+then
+    echo
+    echo "[WARNING] This should not be run as root or using sudo"
+    echo
+fi
+
 # Check argument
 case $1 in
     *.run)
-	INSTALLER_ARCHIVE=$1
+	INSTALLER_ARCHIVE=$(basename "$1")
 	FILENAMEP1=$(echo $INSTALLER_ARCHIVE | cut -d'_' -f1 -)
 	FILENAMEP2=$(echo $INSTALLER_ARCHIVE | cut -d'_' -f2 -)
 	FILENAMEP3=$(echo $INSTALLER_ARCHIVE | cut -d'_' -f3 -)
@@ -488,7 +510,7 @@ esac
 # Check if file exists
 if [[ ! -e $INSTALLER_ARCHIVE ]];
 then
-    echo "[ERROR] File does not exist"
+    echo "[ERROR] File does not exist or is located outside the working directory"
     exit 1
 fi
 
